@@ -3,7 +3,7 @@ from pathlib import Path
 
 
 def get_project_root() -> Path:
-    return Path(__file__).parent.parent.parent
+    return Path(__file__).parent
 
 
 project_root = get_project_root()
